# Hermes storage nodes
[![PyPI version](https://badge.fury.io/py/hermes-storage-nodes.svg)](https://pypi.org/project/hermes-storage-nodes)

A collection of nodes related to data storage

## Installation

### From PyPI

Install the package directly from PyPI using pip:

```bash
pip install hermes-storage-nodes
```

### From Source

Clone the repository and install dependencies:

```bash
git clone https://github.com/node-hermes/hermes-storage-nodes
pip install -e hermes-storage-nodes
```

## Development

This project depends on UV for managing dependencies.
Make sure you have UV installed and set up in your environment.

You can find more information about UV [here](https://docs.astral.sh/uv/getting-started/installation/).

```bash
uv venv
```

```bash
uv sync --all-extras --dev
```
